# Villog is a simple logger for your everyday projects

## Villog

### Usage
**script.py**
```
from villog import Logger

l: Logger = Logger(
    file_path = "test.log",
    encoding = "utf-8-sig",
    time_format = "%Y.%m.%d %H:%M:%S",
    separator = "\t",
    silent = False,
    enable_remove = False,
    strip_content = False
)

l.log(
    content = "test"
)
```

**log.txt** content:
```
2025.01.03 10:48:03	test
```

### Logger functions
- ```log(content)```: logs
- ```change_path(file_path)```: changes the ```file_path```
- ```change_encoding(encoding)```: changes the ```encoding```
- ```change_time_format(time_format)```: changes the ```time_format```
- ```change_separator(separator)```: changes the ```separator```
- ```clear()```: clears the log file

## Writexcel
```
from villog.writexcel import WorkSheet, WorkBook

sheet_1: WorkSheet = WorkSheet(
    name = "Sheet1",
    header = ["header_1", "header_2", "header_3"],
    data = [
        ["data_1", "data_2", "data_3"],
        ["data_4", "data_5", "data_6"]
    ]
)

sheet_2: WorkSheet = WorkSheet(
    name = "Sheet2",
    header = ["header_1", "header_2", "header_3"],
    data = [
        ["data_1", "data_2", "data_3"],
        ["data_4", "data_5", "data_6"]
    ]
)

book: WorkBook = WorkBook(
    name = "Book1",
    sheets = [sheet_1, sheet_2]
)

book.xlsx_create(
    file_path = "test.xlsx"
)
```

## Install
With **pip**:
```
pip install villog
```